pub fn temp_mat_scratch<T: ComplexField>(nrows: usize, ncols: usize) -> StackReqExpand description
returns the stack requirements for creating a temporary matrix with the given dimensions.
pub fn temp_mat_scratch<T: ComplexField>(nrows: usize, ncols: usize) -> StackReqreturns the stack requirements for creating a temporary matrix with the given dimensions.